@@ -2,13 +2,11 @@ package Time::Piece;
 
 use strict;
 
-require Exporter;
-require DynaLoader;
 use Time::Seconds;
 use Carp;
 use Time::Local;
 
-our @ISA = qw(Exporter DynaLoader);
+use Exporter ();
 
 our @EXPORT = qw(
     localtime
@@ -19,9 +17,13 @@ our %EXPORT_TAGS = (
     ':override' => 'internal',
     );
 
-our $VERSION = '1.29_03';
+our $VERSION = '1.29_04';
 
-bootstrap Time::Piece $VERSION;
+require DynaLoader;
+{
+    local *dl_load_flags = \&DynaLoader::dl_load_flags;
+    __PACKAGE__->DynaLoader::bootstrap($VERSION);
+}
 
 my $DATE_SEP = '-';
 my $TIME_SEP = ':';
@@ -133,10 +135,10 @@ sub import {
     my %params;
     map($params{$_}++,@_,@EXPORT);
     if (delete $params{':override'}) {
-        $class->export('CORE::GLOBAL', keys %params);
+        $class->Exporter::export('CORE::GLOBAL', keys %params);
     }
     else {
-        $class->export((caller)[0], keys %params);
+        $class->Exporter::export(scalar caller, keys %params);
     }
 }
 
@@ -458,15 +460,8 @@ sub strftime {
     if (! $time->[c_islocal]) {
         $format =~ s/(%.)/$GMT_REPR{$1} || $1/eg;
     }
-    if (!defined $time->[c_wday]) {
-        if ($time->[c_islocal]) {
-            return _strftime($format, CORE::localtime($time->epoch));
-        }
-        else {
-            return _strftime($format, CORE::gmtime($time->epoch), $time->[c_islocal]);
-        }
-    }
-    return _strftime($format, (@$time)[c_sec..c_isdst], $time->[c_islocal]);
+
+    return _strftime($format, $time->epoch, $time->[c_islocal]);
 }
 
 sub strptime {
